<?php
// Display all errors during development (comment out in production)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Define the root directory dynamically based on the document root
define('ROOT_PATH', $_SERVER['DOCUMENT_ROOT'] . '/bmpanel');

// Now you can include other files using ROOT_PATH
require_once ROOT_PATH . '/config/access.php';
require_once ROOT_PATH . '/include/functions.php';

// Set headers to avoid issues with output buffering
header('Content-Type: application/json');

// Initialize response array
$response = ['status' => 'error', 'message' => 'Unknown request'];

// Capture and decode POST data
$postedData = file_get_contents('php://input');
$data = json_decode($postedData, true);

// Log the received POST data (for debugging purposes)
error_log('Received POST data: ' . print_r($data, true));

// Check if action is set
$action = isset($data['action']) ? $data['action'] : null;

switch ($action) {
    case 'get_users':
        // Function to get users from the database
        $response = get_users();
        break;

    case 'add_user':
        // Function to add a user, using sanitized input
        if (isset($data['username'], $data['email'], $data['password'])) {
            $username = sanitize_input($conn, $data['username']);
            $email = sanitize_input($conn, $data['email']);
            $password = hash_password($data['password']);
            $response = add_user($username, $email, $password);
        } else {
            $response['message'] = 'Missing parameters for add_user';
        }
        break;

    case 'get_income':
        if (!empty($data['terminal_number'])) {  // Check if terminal_number is set
            try {
                $terminal_number = sanitize_input($data['terminal_number']);
                $sql = "SELECT * FROM bp_transaction_info WHERE terminal_id= '$terminal_number' LIMIT 2";
                
                // Execute SQL query
                $response = mysql_execute($sql);
                // Assuming mysql_execute is a function that executes SQL and returns results
            } catch (Exception $e) {
                $response['message'] = 'Error: ' . $e->getMessage();
            }
        } else {
            $response['message'] = 'Terminal number not provided.';
        }
        break;


    default:
        $response['message'] = 'Invalid request: ' . ($action ?: 'No request provided');
        break;
}

// Send the JSON response
echo json_encode($response);
exit();  // Ensure no further output


/**
 * Function to get users from the database
 *
 * @return array JSON encoded list of users
 */
function get_users() {
    global $conn;
    $query = "SELECT id, username, email FROM users";
    $result = $conn->query($query);
    
    if ($result) {
        $users = [];
        while ($row = $result->fetch_assoc()) {
            $users[] = $row;
        }
        return ['status' => 'success', 'data' => $users];
    } else {
        return ['status' => 'error', 'message' => 'Failed to fetch users'];
    }
}

/**
 * Function to add a user to the database
 *
 * @param string $username
 * @param string $email
 * @param string $password
 * @return array JSON encoded success or error message
 */
function add_user($username, $email, $password) {
    global $conn;
    $query = "INSERT INTO users (username, email, password) VALUES ('$username', '$email', '$password')";
    if ($conn->query($query)) {
        return ['status' => 'success', 'message' => 'User added successfully'];
    } else {
        return ['status' => 'error', 'message' => 'Failed to add user: ' . $conn->error];
    }
}

/**
 * Verify the CSRF token
 *
 * @param string $token
 * @return bool
 */
function verify_csrf_token($token) {
    return isset($_SESSION['csrf_token']) && $_SESSION['csrf_token'] === $token;
}
?>
