<?php
require_once("config.php");

try {
    // Fetch the terminal number from the URL
    if (!isset($_GET['terminal_number'])) {
        throw new Exception("Terminal number is not set");
    }

    $terminal_number = $_GET['terminal_number'];

    // Define the current date and time
    $currentDateTime = new DateTime();
    $currentDateTimeFormatted = $currentDateTime->format('Y-m-d H:i:s');

    // Calculate the datetime for the last 24 hours
    $last24HoursDateTime = new DateTime('-24 hours');
    $last24HoursDateTimeFormatted = $last24HoursDateTime->format('Y-m-d H:i:s');

    // Calculate the datetime for the last week
    $lastWeekDateTime = new DateTime('-1 week');
    $lastWeekDateTimeFormatted = $lastWeekDateTime->format('Y-m-d H:i:s');

    // Prepare the SQL query for the last 24 hours
    $sqlLast24Hours = "SELECT SUM(amount) as total_amount_24h FROM direct_payments WHERE terminal = :terminal AND application = 'sib' AND created_at BETWEEN :last24Hours AND :currentDateTime";
    $stmtLast24Hours = $conn->prepare($sqlLast24Hours);
    $stmtLast24Hours->execute([':terminal' => $terminal_number, ':last24Hours' => $last24HoursDateTimeFormatted, ':currentDateTime' => $currentDateTimeFormatted]);
    $resultLast24Hours = $stmtLast24Hours->fetch();

    // Prepare the SQL query for the last week
    $sqlLastWeek = "SELECT SUM(amount) as total_amount_week FROM direct_payments WHERE terminal = :terminal AND application = 'sib' AND created_at BETWEEN :lastWeek AND :currentDateTime";
    $stmtLastWeek = $conn->prepare($sqlLastWeek);
    $stmtLastWeek->execute([':terminal' => $terminal_number, ':lastWeek' => $lastWeekDateTimeFormatted, ':currentDateTime' => $currentDateTimeFormatted]);
    $resultLastWeek = $stmtLastWeek->fetch();

    // Prepare the SQL query for all time
    $sqlAllTime = "SELECT SUM(amount) as total_amount_all FROM direct_payments WHERE terminal = :terminal AND application = 'sib'";
    $stmtAllTime = $conn->prepare($sqlAllTime);
    $stmtAllTime->execute([':terminal' => $terminal_number]);
    $resultAllTime = $stmtAllTime->fetch();

    // Display the results
    /*echo "Total Amount in Last 24 Hours: " . $resultLast24Hours['total_amount_24h'] . "<br>";
    echo "Total Amount in Last Week: " . $resultLastWeek['total_amount_week'] . "<br>";
    echo "Total Amount of All Time: " . $resultAllTime['total_amount_all'] . "<br>";*/

} catch (PDOException $e) {
    // Print error message if database operation fails
    echo "Database error: " . $e->getMessage();
} catch (Exception $e) {
    // Print error message for other errors
    echo "Error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="fa" class="light-style layout-navbar-fixed layout-menu-fixed" dir="rtl" data-theme="theme-default" data-assets-path="def_dashboard/assets/" data-template="vertical-menu-template-no-customizer">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=no, minimum-scale=1.0, maximum-scale=1.0">

    <title>حسابداری سیب</title>

    <meta name="description" content="">

    <!-- Favicon -->
    <!--<link rel="icon" type="image/x-icon" href="def_dashboard/assets/img/favicon/favicon.ico">-->

    <!-- Icons -->
    <link rel="stylesheet" href="def_dashboard/assets/vendor/fonts/boxicons.css">
    <link rel="stylesheet" href="def_dashboard/assets/vendor/fonts/fontawesome.css">
    <link rel="stylesheet" href="def_dashboard/assets/vendor/fonts/flag-icons.css">

    <!-- Core CSS -->
    <link rel="stylesheet" href="def_dashboard/assets/vendor/css/rtl/core.css">
    <link rel="stylesheet" href="def_dashboard/assets/vendor/css/rtl/theme-default.css">
    <link rel="stylesheet" href="def_dashboard/assets/css/demo.css">
    <link rel="stylesheet" href="def_dashboard/assets/vendor/css/rtl/rtl.css">

    <!-- Vendors CSS -->
    <link rel="stylesheet" href="def_dashboard/assets/vendor/libs/perfect-scrollbar/perfect-scrollbar.css">
    <link rel="stylesheet" href="def_dashboard/assets/vendor/libs/typeahead-js/typeahead.css">
    <link rel="stylesheet" href="def_dashboard/assets/vendor/libs/apex-charts/apex-charts.css">

    <!-- Page CSS -->

    <!-- Helpers -->
    <script src="def_dashboard/assets/vendor/js/helpers.js"></script>

    <!--! Template customizer & Theme config files MUST be included after core stylesheets and helpers.js in the <head> section -->
    <!--? Config:  Mandatory theme config file contain global vars & default theme options, Set your preferred theme option in this file.  -->
    <script src="def_dashboard/assets/js/config.js"></script>
  </head>

  <body>
    <!-- Layout wrapper -->
    <div class="layout-wrapper layout-content-navbar">
      <div class="layout-container">
        <!-- Menu -->


        <?php /*include_once("menu.php");*/ ?>

        <!-- / Menu -->

        <!-- Layout container -->
        <div class="layout-page">
          <!-- Navbar -->

        <?php include_once("nav.php"); ?>

          <!-- / Navbar -->

          <!-- Content wrapper -->
          <div class="content-wrapper">
            <!-- Content -->

            <div class="container-xxl flex-grow-1 container-p-y">
              <div class="row">

                <!-- Weekly Order Summary -->
                <div class="col-xl-12 col-12 mb-4">
                  <div class="card h-100">
                    <div class="row row-bordered m-0">
                      <!-- Order Summary -->
                      <div class="col-md-8 col-12 pe-0">
                        <div class="card-header d-flex justify-content-between align-items-center">
                          <h5 class="card-title mb-0">خلاصه سفارش هفتگی</h5>
                          <div class="dropdown primary-font">
                            <button class="btn p-0" type="button" id="orderSummaryOptions" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                              <i class="bx bx-dots-vertical-rounded"></i>
                            </button>
                            <div class="dropdown-menu dropdown-menu-end" aria-labelledby="orderSummaryOptions">
                              <a class="dropdown-item" href="javascript:void(0);">انتخاب همه</a>
                              <a class="dropdown-item" href="javascript:void(0);">تازه سازی</a>
                              <a class="dropdown-item" href="javascript:void(0);">اشتراک گذاری</a>
                            </div>
                          </div>
                        </div>
                        <div class="card-body p-0">
                          <div id="orderSummaryChart"></div>
                        </div>
                      </div>
                      <!-- Sales History -->
                      <div class="col-md-4 col-12 px-0">
                        <div class="card-header d-flex justify-content-between align-items-center">
                          <h5 class="card-title mb-0">نمای کلی فروش‌ها</h5>
                          <div class="dropdown primary-font">
                            <button class="btn p-0" type="button" id="salesOverviewOptions" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                              <i class="bx bx-dots-vertical-rounded"></i>
                            </button>
                            <div class="dropdown-menu dropdown-menu-end" aria-labelledby="salesOverviewOptions">
                              <a class="dropdown-item" href="javascript:void(0);">انتخاب همه</a>
                              <a class="dropdown-item" href="javascript:void(0);">تازه سازی</a>
                              <a class="dropdown-item" href="javascript:void(0);">اشتراک گذاری</a>
                            </div>
                          </div>
                        </div>
                        <div class="card-body">
                          <h6 class="mt-1">هفته قبل</h6>
                          <p class="mb-4">کارایی 45% بهتر نسبت به ماه قبل</p>
                          <ul class="list-unstyled m-0 pt-0">
                            <li class="mb-4">
                              <div class="d-flex align-items-center mb-2">
                                <div class="avatar avatar-sm flex-shrink-0 me-2">
                                  <span class="avatar-initial rounded bg-label-primary"><i class="bx bx-trending-up"></i></span>
                                </div>
                                <div>
                                  <p class="mb-0 text-muted text-nowrap">درآمد این ماه</p>
                                  <small class="fw-semibold text-nowrap"><?= $resultAllTime['total_amount_all']; ?> تومان</small>
                                </div>
                              </div>
                              <div class="progress" style="height: 6px">
                                <div class="progress-bar bg-primary" style="width: 75%" role="progressbar" aria-valuenow="75" aria-valuemin="0" aria-valuemax="100"></div>
                              </div>
                            </li>
                            <li>
                              <div class="d-flex align-items-center mb-2">
                                <div class="avatar avatar-sm flex-shrink-0 me-2">
                                  <span class="avatar-initial rounded bg-label-success"><i class="bx bx-dollar"></i></span>
                                </div>
                                <div>
                                  <p class="mb-0 text-muted text-nowrap">میانگین فروش روزانه</p>
                                  <small class="fw-semibold text-nowrap"><?= $resultAllTime['total_amount_week']; ?> تومان</small>
                                </div>
                              </div>
                              <div class="progress" style="height: 6px">
                                <div class="progress-bar bg-success" style="width: 75%" role="progressbar" aria-valuenow="75" aria-valuemin="0" aria-valuemax="100"></div>
                              </div>
                            </li>
                          </ul>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
                <!--/ Weekly Order Summary -->

                <!-- Marketing Campaigns -->
                <div class="col-xl-12">
                  <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                      <h5 class="card-title mb-0">گزارش دریافت و پرداخت</h5>
                      <div class="dropdown primary-font">
                        <button class="btn p-0" type="button" id="marketingOptions" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                          <i class="bx bx-dots-vertical-rounded"></i>
                        </button>
                        <div class="dropdown-menu dropdown-menu-end" aria-labelledby="marketingOptions">
                          <a class="dropdown-item" href="javascript:void(0);">انتخاب همه</a>
                          <a class="dropdown-item" href="javascript:void(0);">تازه سازی</a>
                          <a class="dropdown-item" href="javascript:void(0);">اشتراک گذاری</a>
                        </div>
                      </div>
                    </div>
                    <div class="card-body">
                      <div class="d-flex align-items-center justify-content-between flex-wrap gap-3">
                        <div class="d-flex justify-content-between align-content-center flex-wrap gap-4">
                          <div class="d-flex align-items-center gap-2">
                            <div id="marketingCampaignChart1"></div>
                            <div>
                              <div class="d-flex align-items-center">
                                <h6 class="mb-0 me-2">25,768</h6>
                                <span class="text-success">(+16.2%)</span>
                              </div>
                              <div class="d-flex align-items-center">
                                <span class="badge badge-dot bg-success me-2"></span> 12 فروردین 1401
                              </div>
                            </div>
                          </div>
                          <div class="d-flex align-items-center gap-2">
                            <div id="marketingCampaignChart2"></div>
                            <div>
                              <div class="d-flex align-items-center">
                                <h6 class="mb-0 me-2">5,352</h6>
                                <span class="text-danger">(-4.9%)</span>
                              </div>
                              <div class="d-flex align-items-center">
                                <span class="badge badge-dot bg-danger me-2"></span> 12 فروردین 1401
                              </div>
                            </div>
                          </div>
                        </div>
                        <a href="javascript:;" class="btn btn-sm btn-primary">مشاهده گزارش</a>
                      </div>
                    </div>
                    <div class="table-responsive">
                      <table class="table border-top">
    <thead>
        <tr>
            <th>ردیف</th>
            <th>دریافت</th>
            <th>پرداخت</th>
            <th>وضعیت</th>
            <th>عمل</th>
        </tr>
    </thead>
    <tbody class="table-border-bottom-0">
        <tr>
            <td class="text-nowrap">
                <img src="def_dashboard/assets/img/icons/brands/fastrack.png" class="me-3" width="22" alt="Fastrack">لورم ایپسوم متن ساختگی
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-up text-success me-2"></i>28.5%</td>
            <td>1,324</td>
            <td><span class="text-success">فعال</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action1" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action1">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/puma.png" class="me-3" width="22" alt="Puma">لورم ایپسوم
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-down text-danger me-2"></i>56.6%</td>
            <td>3,573</td>
            <td><span class="text-success">فعال</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action2" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action2">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/nike.png" class="me-3" width="22" alt="Nike">لورم ایپسوم متن
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-up text-success me-2"></i>23.8%</td>
            <td>12,347</td>
            <td><span class="text-danger">تعطیل</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action3" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action3">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/oneplus.png" class="me-3" width="22" alt="OnePlus">لورم ایپسوم متن
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-up text-success me-2"></i>81.4%</td>
            <td>5,347</td>
            <td><span class="text-success">فعال</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action4" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action4">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/google.png" class="me-3" width="22" alt="Google">لورم ایپسوم متن
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-down text-danger me-2"></i>12.8%</td>
            <td>45,678</td>
            <td><span class="text-danger">تعطیل</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action5" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action5">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/adidas.png" class="me-3" width="22" alt="Adidas">لورم ایپسوم نمونه
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-up text-success me-2"></i>37.9%</td>
            <td>9,120</td>
            <td><span class="text-success">فعال</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action6" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action6">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/sony.png" class="me-3" width="22" alt="Sony">لورم ایپسوم نمونه
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-down text-danger me-2"></i>45.2%</td>
            <td>7,890</td>
            <td><span class="text-danger">تعطیل</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action7" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action7">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <img src="def_dashboard/assets/img/icons/brands/samsung.png" class="me-3" width="22" alt="Samsung">  
            </td>
            <td class="text-nowrap"><i class="bx bx-trending-up text-success me-2"></i>54.7%</td>
            <td>8,765</td>
            <td><span class="text-success">فعال</span></td>
            <td>
                <div class="dropdown">
                    <button class="btn p-0" type="button" id="action8" data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                        <i class="bx bx-dots-vertical-rounded"></i>
                    </button>
                    <div class="dropdown-menu dropdown-menu-end" aria-labelledby="action8">
                        <a class="dropdown-item" href="javascript:void(0);">جزئیات</a>
                        <a class="dropdown-item" href="javascript:void(0);">نوشتن یک نقد و بررسی</a>
                        <a class="dropdown-item" href="javascript:void(0);">دریافت صورتحساب</a>
                    </div>
                </div>
            </td>
        </tr>
    </tbody>
</table>

                    </div>
                  </div>
                </div>
                <!--/ Marketing Campaigns -->
              </div>
            </div>
            <!-- / Content -->

            <!-- Footer -->
            <?php include_once("footer.php"); ?>
            <!-- / Footer -->

            <div class="content-backdrop fade"></div>
          </div>
          <!-- Content wrapper -->
        </div>
        <!-- / Layout page -->
      </div>

      <!-- Overlay -->
      <div class="layout-overlay layout-menu-toggle"></div>

      <!-- Drag Target Area To SlideIn Menu On Small Screens -->
      <div class="drag-target"></div>
    </div>
    <!-- / Layout wrapper -->

    <!-- Core JS -->
    <!-- build:js assets/vendor/js/core.js -->
    <script src="def_dashboard/assets/vendor/libs/jquery/jquery.js"></script>
    <script src="def_dashboard/assets/vendor/libs/popper/popper.js"></script>
    <script src="def_dashboard/assets/vendor/js/bootstrap.js"></script>
    <script src="def_dashboard/assets/vendor/libs/perfect-scrollbar/perfect-scrollbar.js"></script>

    <script src="def_dashboard/assets/vendor/libs/hammer/hammer.js"></script>

    <script src="def_dashboard/assets/vendor/libs/i18n/i18n.js"></script>
    <script src="def_dashboard/assets/vendor/libs/typeahead-js/typeahead.js"></script>

    <script src="def_dashboard/assets/vendor/js/menu.js"></script>
    <!-- endbuild -->

    <!-- Vendors JS -->
    <script src="def_dashboard/assets/vendor/libs/apex-charts/apexcharts.js"></script>

    <!-- Main JS -->
    <script src="def_dashboard/assets/js/main.js"></script>

    <!-- Page JS -->
    <script src="def_dashboard/assets/js/dashboards-ecommerce.js"></script>
  </body>
</html>
